@@ -4,7 +4,10 @@ from copy import deepcopy
 from typing import Dict, List, Optional, Union
 
 from bfcl_eval.eval_checker.multi_turn_eval.func_source_code.long_context import (
-    FILE_CONTENT_EXTENSION, FILES_TAIL_USED, POPULATE_FILE_EXTENSION)
+    FILE_CONTENT_EXTENSION,
+    FILES_TAIL_USED,
+    POPULATE_FILE_EXTENSION,
+)
 
 
 class File:
@@ -285,27 +288,36 @@ class GorillaFileSystem:
         Change the current working directory to the specified folder.
 
         Args:
-            folder (str): The folder of the directory to change to. You can only change one folder at a time.
+            folder (str): The folder of the directory to change to. You can only change one folder level at a time.
 
         Returns:
             current_working_directory (str): The new current working directory path.
         """
+        # turn "../" → "..", "/"  → ""
+        folder = folder.rstrip("/")
+        if folder == "":
+            folder = "/"
+
+        # Check if path is nested
+        if folder not in {".", "..", "/"} and "/" in folder:
+            return {
+                "error": f"cd: {folder}: Unsupported path. Only one folder level at a time is supported."
+            }
+
         # Handle navigating to the parent directory with "cd .."
         if folder == "..":
             if self._current_dir.parent:
                 self._current_dir = self._current_dir.parent
             elif self.root == self._current_dir:
-                return {"error": "Cuurent directory is already the root. Cannot go back."}
+                return {"error": "Current directory is already the root. Cannot go back."}
             else:
                 return {"error": "cd: ..: No such directory"}
             return {}
 
         # Handle absolute or relative paths
         target_dir = self._navigate_to_directory(folder)
-        if isinstance(target_dir, dict):  # Error condition check
-            return {
-                "error": f"cd: {folder}: No such directory. You cannot use path to change directory."
-            }
+        if isinstance(target_dir, dict):  # This means there was an error from _navigate_to_directory
+            return target_dir
         self._current_dir = target_dir
         return {"current_working_directory": target_dir.name}
 
@@ -363,13 +375,13 @@ class GorillaFileSystem:
         if file_name is None:
             return {"terminal_output": content}
         if not self._validate_file_or_directory_name(file_name):
-            return {"error": f"echo: cannot touch '{file_name}': Invalid character"}
+            return {"error": f"echo: cannot write to '{file_name}': Invalid character"}
 
         if file_name:
             if file_name in self._current_dir.contents:
                 self._current_dir._get_item(file_name)._write(content)
             else:
-                self._current_dir._add_file(file_name, content)
+                return {"error": f"echo: cannot write to '{file_name}': No such file"}
         else:
             return {"terminal_output": content}
 
@@ -391,9 +403,9 @@ class GorillaFileSystem:
             if isinstance(item, File):
                 return {"file_content": item._read()}
             else:
-                return {"error": f"cat: {file_name}: Is a directory"}
+                return {"error": f"cat: '{file_name}': Is a directory"}
         else:
-            return {"error": f"cat: {file_name}: No such file or directory"}
+            return {"error": f"cat: '{file_name}': No such file or directory"}
 
     def find(self, path: str = ".", name: Optional[str] = None) -> Dict[str, List[str]]:
         """
@@ -413,7 +425,15 @@ class GorillaFileSystem:
 
         """
         matches = []
-        target_dir = self._current_dir
+        # Navigate to the requested path first
+        target_dir = self._navigate_to_directory(path)
+        if isinstance(target_dir, dict):  # invalid path
+            # Replace the tool name in the error message for clarity
+            original_msg = target_dir.get("error", "")
+            # e.g. "cd: '/foo': No such file or directory" -> "find: '/foo': No such file or directory"
+            if original_msg.startswith("cd:"):
+                return {"error": original_msg.replace("cd:", "find:", 1)}
+            return target_dir
 
         def recursive_search(directory: Directory, base_path: str) -> None:
             for item_name, item in directory.contents.items():
@@ -570,7 +590,7 @@ class GorillaFileSystem:
 
         Args:
             file_name1 (str): The name of the first file in current directory.
-            file_name2 (str): The name of the second file in current directorry.
+            file_name2 (str): The name of the second file in current directory.
 
         Returns:
             diff_lines (str): The differences between the two files.
@@ -598,7 +618,7 @@ class GorillaFileSystem:
 
     def mv(self, source: str, destination: str) -> Dict[str, str]:
         """
-        Move a file or directory from one location to another. so
+        Move a file or directory from one location to another.
 
         Args:
             source (str): Source name of the file or directory to move. Source must be local to the current directory.
@@ -617,7 +637,7 @@ class GorillaFileSystem:
 
         if "/" in destination:
             return {
-                "error": f"mv: no path allowed in destination. Only file name and folder name is supported for this operation."
+                "error": "mv: path not allowed in destination. Provide only a file or directory name."
             }
 
         # Check if the destination is an existing directory
@@ -689,7 +709,7 @@ class GorillaFileSystem:
             if isinstance(item, Directory):
                 if item.contents:  # Check if directory is not empty
                     return {
-                        "error": f"rmdir: failed to remove '{dir_name}': Directory not empty"
+                        "error": f"rmdir: cannot remove '{dir_name}': Directory not empty"
                     }
                 else:
                     self._current_dir.contents.pop(dir_name)
@@ -729,7 +749,7 @@ class GorillaFileSystem:
 
         if "/" in destination:
             return {
-                "error": f"cp: don't allow path in destination. Only file name and folder name is supported for this operation."
+                "error": "cp: path not allowed in destination. Provide only a file or directory name."
             }
         # Check if the destination is an existing directory
         if destination in self._current_dir.contents:
