@@ -19,8 +19,15 @@ from tenacity.stop import stop_after_attempt
 class CohereHandler(BaseHandler):
     client: cohere.ClientV2
 
-    def __init__(self, model_name, temperature) -> None:
-        super().__init__(model_name, temperature)
+    def __init__(
+        self,
+        model_name,
+        temperature,
+        registry_name,
+        is_fc_model,
+        **kwargs,
+    ) -> None:
+        super().__init__(model_name, temperature, registry_name, is_fc_model, **kwargs)
         self.model_style = ModelStyle.COHERE
         self.is_fc_model = True
         self.client = cohere.ClientV2(api_key=os.getenv("COHERE_API_KEY"))
@@ -40,8 +47,14 @@ class CohereHandler(BaseHandler):
             for tool_call in result:
                 parameter_key_value_list = []
                 for parameter_name, parameter_value in tool_call["parameters"].items():
-                    parameter_key_value_list.append("{}={}".format(parameter_name, repr(parameter_value)))
-                execution_list.append("{}({})".format(tool_call["tool_name"], ",".join(parameter_key_value_list)))
+                    parameter_key_value_list.append(
+                        "{}={}".format(parameter_name, repr(parameter_value))
+                    )
+                execution_list.append(
+                    "{}({})".format(
+                        tool_call["tool_name"], ",".join(parameter_key_value_list)
+                    )
+                )
         return execution_list
 
     #### FC methods ####
@@ -101,7 +114,9 @@ class CohereHandler(BaseHandler):
             output_token = response.usage.billed_units.output_tokens
 
         metadata = {
-            "model_responses": chat_turn_to_append.content if chat_turn_to_append.content else None,
+            "model_responses": (
+                chat_turn_to_append.content if chat_turn_to_append.content else None
+            ),
             "tool_calls": model_tool_calls,
             "chat_history": [],
             "input_token": input_token or 0,
@@ -133,11 +148,15 @@ class CohereHandler(BaseHandler):
             if turn_idx == 0:  # we only extract system message from the first turn
                 system_message = extract_system_prompt(turn)
                 if system_message:
-                    inference_data["system_message"] = system_message  # we log system message if necessary
+                    inference_data["system_message"] = (
+                        system_message  # we log system message if necessary
+                    )
             if len(turn) > 0:
                 turns.append(preprocess_chat_turns(turn))
             else:
-                turns.append([])  # for miss_func categories, the turn to supplement function will be empty
+                turns.append(
+                    []
+                )  # for miss_func categories, the turn to supplement function will be empty
         assert len(turns) == len(test_entry["question"])
         test_entry["question"] = turns
         return inference_data
@@ -154,7 +173,9 @@ class CohereHandler(BaseHandler):
         reasoning_content = ""
 
         if len(api_response["tool_calls"]) > 0:  # non empty tool call list
-            model_responses = api_response["tool_calls"]  # list: {"tool_name": , "parameters"}
+            model_responses = api_response[
+                "tool_calls"
+            ]  # list: {"tool_name": , "parameters"}
         else:
             if isinstance(api_response["model_responses"], list):
                 model_responses = []
@@ -185,9 +206,14 @@ class CohereHandler(BaseHandler):
         chat_turns = []
         for message in first_turn_message:
             message_role = message["role"]
-            assert message_role in ["user", "assistant"], "message role must be in ['user', 'assistant']"
+            assert message_role in [
+                "user",
+                "assistant",
+            ], "message role must be in ['user', 'assistant']"
             if message_role == "user":
-                chat_turns.append(cohere.UserChatMessageV2(role="user", content=message["content"]))
+                chat_turns.append(
+                    cohere.UserChatMessageV2(role="user", content=message["content"])
+                )
             else:
                 chat_turns.append(
                     cohere.AssistantChatMessageV2(
@@ -208,7 +234,8 @@ class CohereHandler(BaseHandler):
             message_role = message["role"]
             if message_role == "user":
                 inference_data["chat_turns"].append(
-                    cohere.UserChatMessageV2(role="user", content=message["content"]))
+                    cohere.UserChatMessageV2(role="user", content=message["content"])
+                )
             elif message_role == "assistant":
                 inference_data["chat_turns"].append(
                     cohere.AssistantChatMessageV2(
@@ -220,7 +247,9 @@ class CohereHandler(BaseHandler):
                 raise Exception(f"Role {message_role} is undefined!")
         if inference_data["chat_turns"][-1].role != "user":
             # if last turn is not user turn - we suffixing a user turn at the end of the conversation history
-            inference_data["chat_turns"].append(cohere.UserChatMessageV2(role="user", content=""))
+            inference_data["chat_turns"].append(
+                cohere.UserChatMessageV2(role="user", content="")
+            )
         return inference_data
 
     def _add_assistant_message_FC(
@@ -238,12 +267,16 @@ class CohereHandler(BaseHandler):
             assert (
                 inference_data["chat_turns"][-1].role == "assistant"
             ), "last turn must be tool use turn and from the assistant"
-            assert inference_data["chat_turns"][-1].tool_calls, "last turn must have tool calls"
+            assert inference_data["chat_turns"][
+                -1
+            ].tool_calls, "last turn must have tool calls"
             assert len(inference_data["chat_turns"][-1].tool_calls) == len(
                 execution_results
             ), "Number of execution result must match number of tool calls from last turn!"
             tool_call_messages = []
-            for tool_call, execution_result in zip(inference_data["chat_turns"][-1].tool_calls, execution_results):
+            for tool_call, execution_result in zip(
+                inference_data["chat_turns"][-1].tool_calls, execution_results
+            ):
                 tool_call_id = tool_call.id
                 try:
                     tool_execution_result = ast.literal_eval(execution_result)
