@@ -9,8 +9,15 @@ from bfcl_eval.model_handler.utils import ast_parse
 
 
 class GorillaHandler(BaseHandler):
-    def __init__(self, model_name, temperature) -> None:
-        super().__init__(model_name, temperature)
+    def __init__(
+        self,
+        model_name,
+        temperature,
+        registry_name,
+        is_fc_model,
+        **kwargs,
+    ) -> None:
+        super().__init__(model_name, temperature, registry_name, is_fc_model, **kwargs)
         self.model_style = ModelStyle.GORILLA
 
     def decode_ast(self, result, language, has_tool_call_tag):
