@@ -9,13 +9,19 @@ from overrides import override
 
 
 class GrokHandler(OpenAICompletionsHandler):
-    def __init__(self, model_name, temperature) -> None:
-        super().__init__(model_name, temperature)
+    def __init__(
+        self,
+        model_name,
+        temperature,
+        registry_name,
+        is_fc_model,
+        **kwargs,
+    ) -> None:
+        super().__init__(model_name, temperature, registry_name, is_fc_model, **kwargs)
         self.client = OpenAI(
             base_url="https://api.x.ai/v1",
             api_key=os.getenv("GROK_API_KEY"),
         )
-        self.is_fc_model = "FC" in self.model_name
 
     @override
     def _parse_query_response_prompting(self, api_response: Any) -> dict:
