@@ -19,10 +19,35 @@ from openai.types.responses import Response
 
 
 class OpenAIResponsesHandler(BaseHandler):
-    def __init__(self, model_name, temperature) -> None:
-        super().__init__(model_name, temperature)
+    def __init__(
+        self,
+        model_name,
+        temperature,
+        registry_name,
+        is_fc_model,
+        **kwargs,
+    ) -> None:
+        super().__init__(model_name, temperature, registry_name, is_fc_model, **kwargs)
         self.model_style = ModelStyle.OPENAI_RESPONSES
-        self.client = OpenAI(api_key=os.getenv("OPENAI_API_KEY"))
+        self.client = OpenAI(**self._build_client_kwargs())
+
+    def _build_client_kwargs(self):
+        """Collect OpenAI client keyword arguments from environment variables, but only
+        include them if they are actually present so that we keep the call minimal
+        and rely on the OpenAI SDK's own defaults when possible."""
+
+        kwargs = {}
+
+        if api_key := os.getenv("OPENAI_API_KEY"):
+            kwargs["api_key"] = api_key
+
+        if base_url := os.getenv("OPENAI_BASE_URL"):
+            kwargs["base_url"] = base_url
+
+        if headers_env := os.getenv("OPENAI_DEFAULT_HEADERS"):
+            kwargs["default_headers"] = json.loads(headers_env)
+
+        return kwargs
 
     @staticmethod
     def _substitute_prompt_role(prompts: list[dict]) -> list[dict]:
@@ -36,7 +61,7 @@ class OpenAIResponsesHandler(BaseHandler):
         return prompts
 
     def decode_ast(self, result, language, has_tool_call_tag):
-        if "FC" in self.model_name or self.is_fc_model:
+        if self.is_fc_model:
             decoded_output = []
             for invoked_function in result:
                 name = list(invoked_function.keys())[0]
@@ -47,7 +72,7 @@ class OpenAIResponsesHandler(BaseHandler):
             return default_decode_ast_prompting(result, language, has_tool_call_tag)
 
     def decode_execute(self, result, has_tool_call_tag):
-        if "FC" in self.model_name or self.is_fc_model:
+        if self.is_fc_model:
             return convert_to_function_call(result)
         else:
             return default_decode_execute_prompting(result, has_tool_call_tag)
@@ -73,7 +98,7 @@ class OpenAIResponsesHandler(BaseHandler):
 
         kwargs = {
             "input": message,
-            "model": self.model_name.replace("-FC", ""),
+            "model": self.model_name,
             "store": False,
             "include": ["reasoning.encrypted_content"],
             "reasoning": {"summary": "auto"},
@@ -81,7 +106,11 @@ class OpenAIResponsesHandler(BaseHandler):
         }
 
         # OpenAI reasoning models don't support temperature parameter
-        if "o3" in self.model_name or "o4-mini" in self.model_name or "gpt-5" in self.model_name:
+        if (
+            "o3" in self.model_name
+            or "o4-mini" in self.model_name
+            or "gpt-5" in self.model_name
+        ):
             del kwargs["temperature"]
 
         # Non-reasoning models don't support reasoning parameter
@@ -188,7 +217,7 @@ class OpenAIResponsesHandler(BaseHandler):
 
         kwargs = {
             "input": inference_data["message"],
-            "model": self.model_name.replace("-FC", ""),
+            "model": self.model_name,
             "store": False,
             "include": ["reasoning.encrypted_content"],
             "reasoning": {"summary": "auto"},
@@ -196,7 +225,11 @@ class OpenAIResponsesHandler(BaseHandler):
         }
 
         # OpenAI reasoning models don't support temperature parameter
-        if "o3" in self.model_name or "o4-mini" in self.model_name or "gpt-5" in self.model_name:
+        if (
+            "o3" in self.model_name
+            or "o4-mini" in self.model_name
+            or "gpt-5" in self.model_name
+        ):
             del kwargs["temperature"]
 
         # Non-reasoning models don't support reasoning parameter
